# enquirer-prompt-input [![NPM version](https://img.shields.io/npm/v/enquirer-prompt-input.svg?style=flat)](https://www.npmjs.com/package/enquirer-prompt-input) [![NPM downloads](https://img.shields.io/npm/dm/enquirer-prompt-input.svg?style=flat)](https://npmjs.org/package/enquirer-prompt-input)

Input prompt plugin for [Enquirer](https://github.com/enquirer/enquirer). This is the only prompt type included in Enquirer by default and does not need to be registered separately.

![input prompt example](https://raw.githubusercontent.com/enquirer/enquirer-prompt-input/master/example.gif)

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save enquirer-prompt-input
```

## Usage

```js
var Input = require('enquirer-prompt-input');
var input = new Input({
  name: 'first',
  message: 'What is your name?'
});

input.ask(function(answers) {
  console.log(answers);
});
```

## Enquirer usage

This is the only prompt type included in [enquirer](https://github.com/enquirer/enquirer) by default, so you don't need to register this with enquirer. The following is only an example of how custom prompts are registered.

```js
var Enquirer = require('enquirer');
var enquirer = new Enquirer();

// register the prompt type with enquirer
enquirer.register('input', require('enquirer-prompt-input'));
```

```js
var Enquirer = require('enquirer');
var enquirer = new Enquirer();
enquirer.register('input', require('enquirer-prompt-input'));

var questions = [
  {
    type: 'input',
    name: 'first',
    message: 'First name?',
    default: 'Brian'
  },
  {
    type: 'input',
    name: 'last',
    message: 'Last name?',
    default: 'Woodward'
  }
];

enquirer.ask(questions)
  .then(function(answers) {
    console.log(answers)
  });
```

## Attribution

Based on the `input` prompt in inquirer.

## About

### Related projects

* [enquirer-prompt](https://www.npmjs.com/package/enquirer-prompt): Base prompt module used for creating custom prompt types for Enquirer. | [homepage](https://github.com/jonschlinkert/enquirer-prompt "Base prompt module used for creating custom prompt types for Enquirer.")
* [enquirer-question](https://www.npmjs.com/package/enquirer-question): Question object, used by Enquirer and prompt plugins. | [homepage](https://github.com/enquirer/enquirer-question "Question object, used by Enquirer and prompt plugins.")
* [enquirer](https://www.npmjs.com/package/enquirer): Intuitive, plugin-based prompt system for node.js. Much faster and lighter alternative to Inquirer, with all… [more](https://github.com/enquirer/enquirer) | [homepage](https://github.com/enquirer/enquirer "Intuitive, plugin-based prompt system for node.js. Much faster and lighter alternative to Inquirer, with all the same prompt types and more, but without the bloat.")

### Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

### Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

### Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

### License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/enquirer/enquirer-prompt-input/blob/master/LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.1.30, on October 07, 2016._